Skipperz, by Simon Zozol
=======
![screenshot from skipperz](https://holy-python.com/skipperz/skipperz_screenshot.jpg)


Description
----
In this game, you control a spaceship initially at the right side of the screen.

Some other ships will come from the left

Just skip them


Is this really a game?
----
It's a minimalistic game. 

It is a sound base for whoever wants to make a lateral-scrolling shooter.

Don't refrain to "steal" my work. This is intentionaly a `CC0 licence` (close enough to public domain)

You can try googling "simon zozol skipperz2". As of now (fev 2022), I haven't made it, but mybe, one day.


controls
----
Curently, you can only use the keyboard directional arrows.

Well... actually, you can try to edit `params.py`. It is somewhat technical, but nothing crazy.

I will had other methods later (touchscreen, mouse, joypad)


licence
----
Licence Creative common 0. 

You do whatever you want with this. I take no responsability if it backfires.


Where can I follow the wonderful work of Simon Zozol?
-----
holy-python.com

It might be in French

 